@@ -18,7 +18,6 @@
 -- Definitions of header regexps
 
 local reconf = config['regexp']
-local rspamd_regexp = require "rspamd_regexp"
 
 -- Subject needs encoding
 -- Define encodings types
@@ -415,23 +414,6 @@ reconf['FORGED_MUA_THEBAT_MSGID_UNKNOWN'] = {
 local kmail_mua = 'User-Agent=/^\\s*KMail\\/1\\.\\d+\\.\\d+/H'
 -- KMail common Message-ID template
 local kmail_msgid_common = 'Message-Id=/^<?\\s*\\d+\\.\\d+\\.\\S+\\@\\S+>?$/mH'
-function kmail_msgid (task)
-	local regexp_text = '<(\\S+)>\\|(19[789]\\d|20\\d\\d)(0\\d|1[012])([012]\\d|3[01])([0-5]\\d)([0-5]\\d)\\.\\d+\\.\\1$'
-	local re = rspamd_regexp.create_cached(regexp_text)
-	local header_msgid = task:get_header('Message-Id')
-	if header_msgid then
-		local header_from = task:get_header('From')
-		if header_from and re:match(header_from.."|"..header_msgid) then return true end
-	end
-	return false
-end
--- Summary rule for forged KMail Message-ID header
-reconf['FORGED_MUA_KMAIL_MSGID'] = {
-  re = string.format('(%s) & (%s) & !(%s) & !(%s)', kmail_mua, kmail_msgid_common, 'kmail_msgid', unusable_msgid),
-  score = 3.0,
-  description = 'Message pretends to be send from KMail but has forged Message-ID',
-  group = 'mua'
-}
 -- Summary rule for forged KMail Message-ID header with unknown template
 reconf['FORGED_MUA_KMAIL_MSGID_UNKNOWN'] = {
   re = string.format('(%s) & !(%s) & !(%s)', kmail_mua, kmail_msgid_common, unusable_msgid),
